<?php
/*
=====================================================
 Copyright (c) Ben Croker, ben@putyourlightson.net
 http://www.putyourlightson.net
=====================================================
 File: pi.logmein.php
-----------------------------------------------------
 Purpose: Logs a specified user in
=====================================================
*/

$plugin_info = array(
				'pi_name'			=> 'LogMeIn',
				'pi_version'		=> '1.4',
				'pi_author'			=> 'Ben Croker',
				'pi_author_url'	=> 'http://www.putyourlightson.net/',
				'pi_description'	=> 'Logs a specified user in',
				'pi_usage'			=> Logmein::usage()
			);


class Logmein {	
			
			
	/** ----------------------------------------
	/**  Log the user in now
	/** ----------------------------------------*/

	function now()
	{
		global $DB, $TMPL, $FNS, $SESS, $PREFS, $IN, $LOC;
		
		if ($TMPL->fetch_param('if_member_group'))
		{
			if ($SESS->userdata['group_id'] != $TMPL->fetch_param('if_member_group'))
			{
				return;
			}
		}
		
		if (!$username = $TMPL->fetch_param('username'))
		{
			return 'You must enter a username';
		}
		
		
		/** ----------------------------------------
		/**  Fetch member data
		/** ----------------------------------------*/
		
		$sql = "SELECT exp_members.password, exp_members.unique_id, exp_members.member_id, exp_members.group_id
					FROM   exp_members, exp_member_groups
					WHERE  username = '$username'
					AND	exp_members.group_id = exp_member_groups.group_id
					AND	   exp_member_groups.site_id = '".$DB->escape_str($PREFS->ini('site_id'))."'";
				
		$query = $DB->query($sql);
		
		
		/** ----------------------------------------
		/**  Set cookie expiration
		/** ----------------------------------------*/
		
		// set default expiration to one day
		$expire = 60*60*24;		
		
		if ($TMPL->fetch_param('expire'))
		{
			$expire = $TMPL->fetch_param('expire');
		}
	
	
		/** ----------------------------------------
		/**  Set cookies
		/** ----------------------------------------*/
		
		$FNS->set_cookie($SESS->c_expire , time() + $expire, $expire);
		$FNS->set_cookie($SESS->c_uniqueid , $query->row['unique_id'], $expire);	   
		$FNS->set_cookie($SESS->c_password , $query->row['password'],  $expire);  
		$FNS->set_cookie($SESS->c_anon , 1,  $expire);
		
		
		/** ----------------------------------------
		/**  Create a new session
		/** ----------------------------------------*/
		
		$SESS->create_new_session($query->row['member_id']);
		$SESS->userdata['username']  = $username;
		$SESS->userdata['group_id']  = $query->row['group_id'];
		
		
		/** ----------------------------------------
		/**  Update stats
		/** ----------------------------------------*/
 
		$data = array(
			'member_id'	=> $SESS->userdata('member_id'),
			'name'		=> ($SESS->userdata['screen_name'] == '') ? $SESS->userdata['username'] : $SESS->userdata['screen_name'],
			'ip_address'	=> $IN->IP,
			'date'		=> $LOC->now,
			'anon'		=> 'y',
			'site_id'		=> $PREFS->ini('site_id')
		);
	   
		$DB->query($DB->update_string('exp_online_users', $data, array("ip_address" => $IN->IP, "member_id" => $data['member_id'], )));
	}
	/* END */
	
	
	/** ----------------------------------------
	/**  Log the user out
	/** ----------------------------------------*/

	function logout()
	{
		global $DB, $SESS, $IN, $PREFS, $FNS;
		
		/** ----------------------------------------
		/**  Kill the session and cookies
		/** ----------------------------------------*/

		$DB->query("DELETE FROM exp_online_users WHERE site_id = '".$DB->escape_str($PREFS->ini('site_id'))."' AND ip_address = '".$IN->IP."' AND member_id = '".$SESS->userdata('member_id')."'");

		$DB->query("DELETE FROM exp_sessions WHERE session_id = '".$SESS->userdata['session_id']."'");
				
		$FNS->set_cookie($SESS->c_uniqueid);	   
		$FNS->set_cookie($SESS->c_password);   
		$FNS->set_cookie($SESS->c_session);   
		$FNS->set_cookie($SESS->c_expire);   
		$FNS->set_cookie($SESS->c_anon);  
		$FNS->set_cookie('read_topics');  
		$FNS->set_cookie('tracker');  
	}
	/* END */
	
	
// ----------------------------------------
//  Plugin Usage
// ----------------------------------------

// This function describes how the plugin is used.
//  Make sure and use output buffering

function usage()
{
ob_start(); 
?>

Put the following line into any template to log the current visitor in. 

{exp:logmein:now username="priveleged_guest" if_member_group="3" expire="300"}

The username parameter is required.
The if_member_group parameter is optional and defines the member group id that the current user must belong to.
The expire parameter is optional and sets the expiration time in seconds of the cookie.

To log the current member out use:

{exp:logmein:logout}

<?php
$buffer = ob_get_contents();
	
ob_end_clean(); 

return $buffer;
}
/* END */


}
// END CLASS
?>